option mcp=miles;
$TITLE  Multiregion CGE Model -- GTAP

*	Notes:
*		(1)This is the GTAP model implemented in MPSGE.
*		(2)Variables, equations and GAMS keywords are in UPPER case.
*			Sets and parameters are in lower case.

*	Read the dataset using the standard routine:

$ONEMPTY
$INCLUDE mrtdata 
$OFFEMPTY

$ONTEXT

$MODEL:GTAP

$SECTORS:
        C(r)                	   	! Private consumption
        G(r)                    	! Public provision
        Y(i,r)$vom(i,r)         	! Output
        M(i,r)$vim(i,r)         	! Import aggregation
        A(d,i,r)$va(d,i,r)      	! Armington aggregation of domestic and imports
        YT                      	! Transport 

$COMMODITIES:
        PC(r)				! Private demand
        PG(r)				! Public provision
	PY(i,r)$(vom(i,r))              ! Output price
        PM(i,r)$vim(i,r)		! Import price
        PA(d,i,r)$va(d,i,r)		! Armington composite price
        PF(f,r)$evoa(f,r)		! Factor price
        PT                      	! Transport services

$CONSUMERS:
        RA(r)           		! Representative agent

$AUXILIARY:
        EXPAND(R)          ! CAPITAL EXPANSION IN STEADY STATE
        CONTRACT(R)        ! CAPITAL CONTRACTION IN STEADY STATE

*       Production of output Y:

$PROD:Y(i,r)$(vom(i,r)>0)  S:0  va:subva(i)
        O:PY(i,r)	Q:vom(i,r)    A:RA(r) T:ty(i,r)
        I:PA("i",j,r)	Q:vafm(J,i,r) A:RA(r) T:ti(j,i,r) 
        I:PF(f,r)	Q:vfm(f,i,r)  P:pf0(f,i,r) A:RA(r) T:tf(f,i,r) va:

$REPORT:
        V:FD(f,i,r)     I:PF(f,r)       PROD:Y(i,r)

*       Armington aggregation over domestic versus imports:

$PROD:A(d,i,r)$va(d,i,r)  S:esubdm(i)
        O:PA(d,i,r)		Q:va(d,i,r)
        I:PY(i,r)		Q:vd(d,i,r)
        I:PM(i,r)		Q:vm(d,i,r)

*       Armington aggregation across imports from different countries:

$PROD:M(i,r)$(vim(i,r)>0)   S:esubmm(i)   s.TL:0
        O:PM(i,r)       Q:vim(i,r)
        I:PY(i,s)       Q:vxmd(i,s,r)  P:pmx0(i,s,r)	s.TL:
+                       A:RA(S) T:TX(i,s,r) A:RA(r) T:(tm(i,s,r)*(1+tx(i,s,r)))
        I:PT#(s)        Q:vtwr(i,s,r)  P:pmt0(i,s,r)	s.TL: 
+			A:RA(r) 

*       Demand for public output G:

$PROD:G(r)  S:1
        O:PG(r)         Q:vg(r)
        I:PA("g",i,r)   Q:vgm(i,r)  P:pg0(i,r)  A:RA(r) T:tg(i,r) 

*       Private consumption C:

$PROD:C(r)  S:1
        O:PC(r)         Q:vp(r)
        I:PA("c",i,r)   Q:vpm(i,r)  P:pc0(i,r)  A:RA(r) T:tp(i,r)

*       Inter-national transport services (Cobb-Douglas) YT:

$PROD:YT  S:1
        O:PT			Q:vt
        I:PY(i,r)		Q:vst(i,r)

*       Final demand over consumption, savings/investment and government 
*       services (Cobb-Douglas):

$DEMAND:RA(r)  
        E:PF(f,r)		Q:evoa(f,r)
        E:PC(num)		Q:vb(r)
	D:PY(cgd,r)		Q:vi(r)
        D:PG(r)			Q:vg(r)
        D:PC(r)			Q:vp(r)
  	E:PF("capital",r)       Q:(evoa("capital",r)*switch)     R:EXPAND(R)
  	E:PF("capital",r)       Q:(-evoa("capital",r)*switch)    R:CONTRACT(R)

*accumulation equations for Solow-type growth

$CONSTRAINT:EXPAND(R)
  EXPAND(R) =G=  (Y("cgd",r)-1);

$CONSTRAINT:CONTRACT(R)
  CONTRACT(R) =G= -(Y("cgd",r)-1);

$OFFTEXT
$SYSINCLUDE mpsgeset GTAP

*	Check the benchmark:

GTAP.ITERLIM = 0;
$INCLUDE GTAP.GEN
SOLVE GTAP USING MCP;

*	Fix a numeraire to permit comparison with MCP:

RA.FX(num) = RA.L(num);

*	Do a cleanup calculation:

GTAP.ITERLIM = 8000;
$INCLUDE GTAP.GEN
SOLVE GTAP USING MCP;

