$TITLE  Multiregion CGE Model -- dmr-deMelo style

*	Notes:
*		(1)This is a dmr-deMelo style model implemented in MPSGE.
*                  It is basically a multi-sector version of the 123 model.
*		(2)Variables, equations and GAMS keywords are in UPPER case.
*			Sets and parameters are in lower case.

*	Read the dataset using the standard routine:

$ONEMPTY
$INCLUDE mrtdata 

$OFFEMPTY

$ONTEXT

$MODEL:dmr

$SECTORS:
        C(r)                	   	! Private consumption
        G(r)                    	! Public provision
        Y(i,r)$vom(i,r)         	! Output
        M(i,r)$vim(i,r)         	! Import aggregation
        A(d,i,r)$va(d,i,r)      	! Armington aggregation of domestic and imports
        YT                      	! Transport 

$COMMODITIES:
        PC(r)				! Private demand
        PG(r)				! Public provision
	PD(i,r)$(vdm(i,r))		! Domestic price
        PX(i,r)$(vxm(i,r))		! Export price
	PM(i,r)$vim(i,r)		! Import price
        PA(d,i,r)$va(d,i,r)		! Armington composite price
        PF(f,r)$evoa(f,r)		! Factor price
        PT                      	! Transport services

$CONSUMERS:
        RA(r)           		! Representative agent


*       Production of output Y with a CET between exports and domestic output:

$PROD:Y(i,r)$(vom(i,r)>0)  S:0  T:2  va:subva(i)
        O:PD(i,r)	Q:vdm(i,r)    A:RA(r) T:ty(i,r)
        O:PX(i,r)	Q:vxm(i,r)    A:RA(r) T:ty(i,r)
        I:PA("i",j,r)	Q:vafm(J,i,r) A:RA(r) T:ti(j,i,r) 
        I:PF(f,r)	Q:vfm(f,i,r)  P:pf0(f,i,r) A:RA(r) T:tf(f,i,r) va:

$REPORT:
  	V:YD(i,r) O:PD(i,r)       PROD:Y(i,r)
        V:YX(i,r) O:PX(i,r)       PROD:Y(i,r)

*       Armington aggregation over domestic versus imports:

$PROD:A(d,i,r)$va(d,i,r)  S:esubdm(i)
        O:PA(d,i,r)		Q:va(d,i,r)
        I:PD(i,r)		Q:vd(d,i,r)
        I:PM(i,r)		Q:vm(d,i,r)

*       Armington aggregation across imports from different countries:

$PROD:M(i,r)$(vim(i,r)>0)   S:esubmm(i)   s.TL:0
        O:PM(i,r)       Q:vim(i,r)
        I:PX(i,s)       Q:vxmd(i,s,r)  P:pmx0(i,s,r)	s.TL:
+                       A:RA(S) T:TX(i,s,r) A:RA(r) T:(tm(i,s,r)*(1+tx(i,s,r)))
        I:PT#(s)        Q:vtwr(i,s,r)  P:pmt0(i,s,r)	s.TL: 
+			A:RA(r) T:tm(i,s,r)


*       Demand for public output G:

$PROD:G(r)  S:1
        O:PG(r)         Q:vg(r)
        I:PA("g",i,r)   Q:vgm(i,r)  P:pg0(i,r)  A:RA(r) T:tg(i,r) 

*       Private consumption C:

$PROD:C(r)  S:1
        O:PC(r)         Q:vp(r)
        I:PA("c",i,r)   Q:vpm(i,r)  P:pc0(i,r)  A:RA(r) T:tp(i,r)

*       Inter-national transport services (Cobb-Douglas) YT:

$PROD:YT  S:1
        O:PT			Q:vt
        I:PX(i,r)		Q:vst(i,r)

*       Final demand over consumption, savings/investment and government 
*       services.  Note that government and investment are fixed.

$DEMAND:RA(r)  
        E:PF(f,r)		Q:evoa(f,r)
        E:PC(num)		Q:vb(r)
	E:PD(cgd,r)		Q:-vi(r)
        E:PG(r)			Q:-vg(r)
        D:PC(r)			Q:vp(r)

$OFFTEXT
$SYSINCLUDE mpsgeset dmr

*	Check the benchmark:

dmr.ITERLIM = 0;
$INCLUDE dmr.GEN
SOLVE dmr USING MCP;

*	Fix a numeraire to permit comparison with MCP:

RA.FX(num) = RA.L(num);

*	Do a cleanup calculation:

dmr.ITERLIM = 8000;
$INCLUDE dmr.GEN
SOLVE dmr USING MCP;

